@@ -534,6 +534,11 @@ class _Slice(CubePartition):
         """str description of this slice, which it takes from its rows-dimension."""
         return self._rows_dimension.description
 
+    @lazyproperty
+    def has_scale_means(self):
+        """True if the slice has valid columns scale mean."""
+        return True if self.columns_scale_mean is not None else False
+
     @lazyproperty
     def inserted_column_idxs(self):
         """tuple of int index of each subtotal column in slice."""
@@ -610,6 +615,54 @@ class _Slice(CubePartition):
             )
         )
 
+    @lazyproperty
+    def pairwise_significance_t_stats(self):
+        """3D ndarray of pairwise-significance t-stats matrices for each subvariable.
+
+        Each subvariable pairwise significance matrix is a 2D ndarray of the t-stats
+        for the selected subvariable index (the selected column).
+        """
+
+        # If overlaps are defined, calculate significance based on them
+        if (
+            self.dimension_types[-1] == DT.MR
+            and self._cube.overlaps is not None
+            and self._cube.valid_overlaps is not None
+        ):
+            return self._assembler.pairwise_significance_t_stats
+
+        # Wrap the legacy objects in a 3D ndarray, so that's interpretable by exporter
+        return np.array(
+            [
+                PairwiseSignificance(self).values[column_idx].t_stats
+                for column_idx in range(len(self.column_labels))
+            ]
+        )
+
+    @lazyproperty
+    def pairwise_significance_p_vals(self):
+        """3D ndarray of pairwise-significance p-vals matrices for each subvariable.
+
+        Each subvariable pairwise significance matrix is a 2D ndarray of the p-vals
+        for the selected subvariable index (the selected column).
+        """
+
+        # If overlaps are defined, calculate significance based on them
+        if (
+            self.dimension_types[-1] == DT.MR
+            and self._cube.overlaps is not None
+            and self._cube.valid_overlaps is not None
+        ):
+            return self._assembler.pairwise_significance_p_vals
+
+        # Wrap the legacy objects in a 3D ndarray, so that's interpretable by exporter
+        return np.array(
+            [
+                PairwiseSignificance(self).values[column_idx].p_vals
+                for column_idx in range(len(self.column_labels))
+            ]
+        )
+
     @lazyproperty
     def pairwise_significance_tests(self):
         """tuple of _ColumnPairwiseSignificance tests.
@@ -916,6 +969,22 @@ class _Slice(CubePartition):
     def shape(self):
         return self.counts.shape
 
+    @lazyproperty
+    def share_sum(self):
+        """2D optional np.float64 ndarray of share of sum value for each table cell.
+
+        Raises `ValueError` if the cube-result does not include a sum cube-measure.
+
+        Share of sum is the sum of each subvar item divided by the TOTAL number of
+        items.
+        """
+        try:
+            return self._assembler.share_sum
+        except ValueError:
+            raise ValueError(
+                "`.share_sum` is undefined for a cube-result without a sum measure"
+            )
+
     @lazyproperty
     def smoothed_dimension_dict(self):
         """dict, smoothed column dimension definition"""
@@ -1105,7 +1174,7 @@ class _Slice(CubePartition):
     @lazyproperty
     def _column_variances(self):
         """Variance for column percentages."""
-        p = self.counts / self.columns_margin
+        p = self.column_proportions
         return p * (1 - p)
 
     @lazyproperty
@@ -1165,17 +1234,7 @@ class _Slice(CubePartition):
     @lazyproperty
     def _row_variance(self):
         """2D np.float64 ndarray of row-percentage variance for each cell."""
-        # --- rows-margin is a vector that represents a column (to the right of the
-        # --- crosstab), or a table-like structure, in the case of Multiple Response.
-        # --- We need to divide all values in the crosstab by it and therefore need to
-        # --- cast it to an actual column, when it's not a table already, because
-        # --- of how NumPy does broadcasting.
-        rows_margin = (
-            self.rows_margin  # --- No need to inflate (MR dim involved)
-            if len(self.rows_margin.shape) > 1
-            else self.rows_margin[:, np.newaxis]  # --- Inflate for correct broadcasting
-        )
-        p = self.counts / rows_margin
+        p = self.row_proportions
         return p * (1 - p)
 
     @lazyproperty
@@ -1269,6 +1328,11 @@ class _Strand(CubePartition):
         """
         return self._assembler.inserted_row_idxs
 
+    @lazyproperty
+    def has_scale_means(self):
+        """True if the strand has valid scale means."""
+        return True if self.scale_mean is not None else False
+
     @lazyproperty
     def is_empty(self):
         return any(s == 0 for s in self.shape)
@@ -1435,6 +1499,22 @@ class _Strand(CubePartition):
         """dict, row dimension definition"""
         return self._rows_dimension._dimension_dict
 
+    @lazyproperty
+    def share_sum(self):
+        """1D np.float64 ndarray of share of sum for each row of strand.
+
+        Raises `ValueError` if the cube-result does not include a sum cube-measure.
+
+        Share of sum is the sum of each subvar item divided by the TOTAL number of
+        items.
+        """
+        try:
+            return self._assembler.share_sum
+        except ValueError:
+            raise ValueError(
+                "`.share_sum` is undefined for a cube-result without a sum measure"
+            )
+
     @lazyproperty
     def stddev(self):
         """1D np.float64 ndarray of stddev for each row of strand.
