@@ -218,6 +218,19 @@ class _RawDimension(object):
             for category in self._dimension_dict["type"].get("categories", [])
         }
 
+    @lazyproperty
+    def _is_logical_type(self):
+        """True if dimension-dict has the categories equal to those of the logical type.
+
+        Logical type has exactly three categories with IDs [-1, 0, 1]. This type is
+        used to define the selections dimension of the multiple response type, when it
+        follows the subvariables dimension.
+        """
+        return [
+            category.get("id")
+            for category in self._dimension_dict["type"].get("categories", [])
+        ] == [1, 0, -1]
+
     @lazyproperty
     def _is_array_cat(self):
         """True if a categorical dimension_dict belongs to an array pair.
@@ -255,6 +268,7 @@ class _RawDimension(object):
             next_raw_dimension._base_type == "categorical"
             and next_raw_dimension._has_selected_category
             and next_raw_dimension._alias == self._alias
+            and next_raw_dimension._is_logical_type
         )
         return DT.MR if is_mr_subvar else DT.CA
 
@@ -268,10 +282,18 @@ class _RawDimension(object):
         """
         # ---an array categorical is either CA_CAT or MR_CAT---
         if self._is_array_cat:
-            return DT.MR_CAT if self._has_selected_category else DT.CA_CAT
+            return (
+                DT.MR_CAT
+                if self._has_selected_category and self._is_logical_type
+                else DT.CA_CAT
+            )
 
         # ---what's left is logical or plain-old categorical---
-        return DT.LOGICAL if self._has_selected_category else DT.CAT
+        return (
+            DT.LOGICAL
+            if self._has_selected_category and self._is_logical_type
+            else DT.CAT
+        )
 
 
 class Dimension(object):
@@ -882,11 +904,23 @@ class _Subtotals(Sequence):
                 continue
 
             # ---skip any malformed subtotal-dicts---
-            if not {"anchor", "args", "name"}.issubset(insertion_dict.keys()):
+            if not {"anchor", "name"}.issubset(insertion_dict.keys()):
+                continue
+
+            # ---use "new style" kwargs defining positive terms if available---
+            # ---but if missing, use "old style" args defining positive terms---
+            positive = insertion_dict.get("kwargs", {}).get(
+                "positive"
+            ) or insertion_dict.get("args", [])
+
+            negative = insertion_dict.get("kwargs", {}).get("negative", [])
+
+            # ---must have positive or negative elements---
+            if not (positive or negative):
                 continue
 
             # ---skip if doesn't reference at least one non-missing element---
-            if not self._element_ids.intersection(insertion_dict["args"]):
+            if not self._element_ids.intersection(positive + negative):
                 continue
 
             # ---an insertion-dict that successfully runs this gauntlet
@@ -949,11 +983,12 @@ class _Subtotal(object):
         Any element id not present in the dimension or present but
         representing missing data is excluded.
         """
-        return tuple(
-            arg
-            for arg in self._subtotal_dict.get("args", [])
-            if arg in self._valid_elements.element_ids
-        )
+        # ---Prefer positive "kwargs" over "args" so we can migrate---
+        positive = self._subtotal_dict.get("kwargs", {}).get(
+            "positive"
+        ) or self._subtotal_dict.get("args", [])
+
+        return tuple(arg for arg in positive if arg in self._valid_elements.element_ids)
 
     @lazyproperty
     def addend_idxs(self):
