@@ -24,7 +24,6 @@ from cr.cube.matrix.cubemeasure import BaseCubeResultMatrix
 from cr.cube.matrix.measure import SecondOrderMeasures
 from cr.cube.matrix.subtotals import (
     NanSubtotals,
-    SumDiffSubtotals,
     SumSubtotals,
     TableStdErrSubtotals,
     ZscoreSubtotals,
@@ -168,6 +167,38 @@ class Assembler(object):
         """
         return self._assemble_matrix(self._measures.means.blocks)
 
+    @lazyproperty
+    def pairwise_significance_p_vals(self):
+        """3D optional np.float64 ndarray of overlaps-p_vals matrices for each subvar.
+
+        Raises `ValueError if the cube-result does not include `overlaps`
+        and `valid_overlaps` cube-measures.
+        """
+        return np.array(
+            [
+                self._assemble_matrix(
+                    self._measures.pairwise_p_vals_for_subvar(subvar_idx).blocks
+                )
+                for subvar_idx in range(len(self.column_labels))
+            ]
+        )
+
+    @lazyproperty
+    def pairwise_significance_t_stats(self):
+        """3D optional np.float64 ndarray of overlaps-t_stats matrices for each subvar.
+
+        Raises `ValueError if the cube-result does not include `overlaps`
+        and `valid_overlaps` cube-measures.
+        """
+        return np.array(
+            [
+                self._assemble_matrix(
+                    self._measures.pairwise_t_stats_for_subvar(subvar_idx).blocks
+                )
+                for subvar_idx in range(len(self.column_labels))
+            ]
+        )
+
     @lazyproperty
     def pvalues(self):
         """2D np.float64/np.nan ndarray of p-value for each matrix cell."""
@@ -252,7 +283,7 @@ class Assembler(object):
         # --- an X_MR slice produces a 2D rows-margin (each cell has its own N) ---
         if self._columns_dimension.dimension_type == DT.MR_SUBVAR:
             return self._assemble_matrix(
-                SumDiffSubtotals.blocks(
+                SumSubtotals.blocks(
                     self._cube_result_matrix.rows_margin, self._dimensions
                 )
             )
@@ -262,6 +293,14 @@ class Assembler(object):
             self._cube_result_matrix.rows_margin, self._row_subtotals, self._row_order
         )
 
+    @lazyproperty
+    def share_sum(self):
+        """2D optional np.float64 ndarray of share of sum for each cell.
+
+        Raises `ValueError` if the cube-result does not include a sum cube-measure.
+        """
+        return self._assemble_matrix(self._measures.share_sum.blocks)
+
     @lazyproperty
     def sums(self):
         """2D optional np.float64 ndarray of sum for each cell.
