@@ -5,9 +5,10 @@
 from __future__ import division
 
 import numpy as np
+from scipy.stats import t
 
 from cr.cube.matrix.cubemeasure import CubeMeasures
-from cr.cube.matrix.subtotals import SumDiffSubtotals, SumSubtotals, NanSubtotals
+from cr.cube.matrix.subtotals import SumSubtotals, NanSubtotals
 from cr.cube.util import lazyproperty
 
 
@@ -50,6 +51,18 @@ class SecondOrderMeasures(object):
         """_Means measure object for this cube-result"""
         return _Means(self._dimensions, self, self._cube_measures)
 
+    def pairwise_p_vals_for_subvar(self, subvar_idx):
+        """_PairwiseSigPVals measure object for this cube-result and selected subvar."""
+        return _PairwiseSigPVals(
+            self._dimensions, self, self._cube_measures, subvar_idx
+        )
+
+    def pairwise_t_stats_for_subvar(self, subvar_idx):
+        """_PairwiseSigTStats measure object for this cube-result and selected subvar."""
+        return _PairwiseSigTStats(
+            self._dimensions, self, self._cube_measures, subvar_idx
+        )
+
     @lazyproperty
     def row_proportions(self):
         """_RowProportions measure object for this cube-result."""
@@ -70,6 +83,11 @@ class SecondOrderMeasures(object):
         """1D np.float64 ndarray of unweighted-N for each matrix row."""
         return self._cube_measures.unweighted_cube_counts.rows_pruning_base
 
+    @lazyproperty
+    def share_sum(self):
+        """_ShareSum measure object for this cube-result"""
+        return _ShareSum(self._dimensions, self, self._cube_measures)
+
     @lazyproperty
     def sums(self):
         """_Sums measure object for this cube-result"""
@@ -208,7 +226,7 @@ class _ColumnProportions(_BaseSecondOrderMeasure):
         Column-proportions are counts divided by the column base, except that they are
         undefined for columns with subtotal differences.
         """
-        count_blocks = SumDiffSubtotals.blocks(
+        count_blocks = SumSubtotals.blocks(
             self._weighted_cube_counts.weighted_counts,
             self._dimensions,
             diff_cols_nan=True,
@@ -259,7 +277,9 @@ class _ColumnUnweightedBases(_BaseSecondOrderMeasure):
         # --- shape of the intersections. This works in the X_CAT case because each row
         # --- of subtotal-columns is the same. In the X_MR case there can be no subtotal
         # --- columns and so it is just an empty row that is broadcast.
-        shape = SumSubtotals.intersections(self._base_values, self._dimensions).shape
+        shape = SumSubtotals.intersections(
+            self._base_values, self._dimensions, diff_cols_nan=True
+        ).shape
         columns_base = self._subtotal_columns[0]
         return np.broadcast_to(columns_base, shape)
 
@@ -275,7 +295,9 @@ class _ColumnUnweightedBases(_BaseSecondOrderMeasure):
         # --- though, see below. This wouldn't work on MR-columns but there can be no
         # --- subtotal columns on an MR dimension (X_MR slice) so that case never
         # --- arises.
-        return SumSubtotals.subtotal_columns(self._base_values, self._dimensions)
+        return SumSubtotals.subtotal_columns(
+            self._base_values, self._dimensions, diff_cols_nan=True
+        )
 
     @lazyproperty
     def _subtotal_rows(self):
@@ -288,7 +310,9 @@ class _ColumnUnweightedBases(_BaseSecondOrderMeasure):
         # --- column-base as all other cells in that column. Note that this initial
         # --- subtotal-rows matrix is used only for its shape (and when it is empty)
         # --- because it computes the wrong cell values for this case.
-        subtotal_rows = SumSubtotals.subtotal_rows(self._base_values, self._dimensions)
+        subtotal_rows = SumSubtotals.subtotal_rows(
+            self._base_values, self._dimensions, diff_cols_nan=True
+        )
 
         # --- in the "no-row-subtotals" case, short-circuit with a (0, ncols) array
         # --- return value, both because that is the right answer, but also because the
@@ -331,7 +355,9 @@ class _ColumnWeightedBases(_BaseSecondOrderMeasure):
         # --- shape of the intersections. This works in the X_CAT case because each row
         # --- of subtotal-columns is the same. In the X_MR case there can be no subtotal
         # --- columns so an empty row is broadcast to shape.
-        shape = SumSubtotals.intersections(self._base_values, self._dimensions).shape
+        shape = SumSubtotals.intersections(
+            self._base_values, self._dimensions, diff_cols_nan=True
+        ).shape
         intersections_row = self._subtotal_columns[0]
         return np.broadcast_to(intersections_row, shape)
 
@@ -343,7 +369,9 @@ class _ColumnWeightedBases(_BaseSecondOrderMeasure):
         """
         # --- Summing works on columns because column-proportion denominators add along
         # --- that axis.
-        return SumSubtotals.subtotal_columns(self._base_values, self._dimensions)
+        return SumSubtotals.subtotal_columns(
+            self._base_values, self._dimensions, diff_cols_nan=True
+        )
 
     @lazyproperty
     def _subtotal_rows(self):
@@ -355,7 +383,9 @@ class _ColumnWeightedBases(_BaseSecondOrderMeasure):
         # --- the subtotal-rows matrix because these don't add. Note that this initial
         # --- subtotal-rows matrix is used only for its shape because it computes the
         # --- wrong values.
-        subtotal_rows = SumSubtotals.subtotal_rows(self._base_values, self._dimensions)
+        subtotal_rows = SumSubtotals.subtotal_rows(
+            self._base_values, self._dimensions, diff_cols_nan=True
+        )
         # --- in the "no-row-subtotals" case, short-circuit with a (0, ncols) array
         # --- return value, both because that is the right answer, but also because the
         # --- non-empty columns-base array cannot be broadcast into that shape.
@@ -378,6 +408,98 @@ class _Means(_BaseSecondOrderMeasure):
         )
 
 
+class _PairwiseSigTStats(_BaseSecondOrderMeasure):
+    """Provides pairwise significance t-stats measure for matrix and selected subvar.
+
+    Pairwise significance is calculated for each selected subvar (column) separately.
+    """
+
+    def __init__(
+        self, dimensions, second_order_measures, cube_measures, selected_subvar_idx
+    ):
+        super(_PairwiseSigTStats, self).__init__(
+            dimensions, second_order_measures, cube_measures
+        )
+        self._selected_subvar_idx = selected_subvar_idx
+
+    @lazyproperty
+    def blocks(self):
+        """2D array of the four 2D "blocks" making up this measure."""
+        return NanSubtotals.blocks(self._t_stats, self._dimensions)
+
+    @lazyproperty
+    def _n_rows(self):
+        """int number of rows in the matrix."""
+        return self._cube_measures.cube_overlaps.overlaps.shape[0]
+
+    @lazyproperty
+    def _n_subvars(self):
+        """int number of columns (subvariables) in the matrix."""
+        return self._cube_measures.cube_overlaps.overlaps.shape[1]
+
+    @lazyproperty
+    def _t_stats(self):
+        """2D ndarray of float64 representing t-stats for pairwise MR testing.
+
+        For each (category) row, we calculate the test statistic of the overlap between
+        columns (subvariables) of the crossing MR variable. To do that we have to
+        iterate across all categories (rows), and then across all subvars (columns).
+        Each of these iterations produces a single number for the test statistic, so we
+        end up with n_rows x n_cols 2-dimensional ndarray.
+        """
+        return np.array(
+            [
+                [
+                    _PairwiseSignificaneBetweenSubvariablesHelper(
+                        self._cube_measures.cube_overlaps.overlaps[row_idx],
+                        self._cube_measures.cube_overlaps.valid_overlaps[row_idx],
+                        self._selected_subvar_idx,
+                        subvar_idx,
+                    ).t_stats
+                    for subvar_idx in range(self._n_subvars)
+                ]
+                for row_idx in range(self._n_rows)
+            ]
+        )
+
+
+class _PairwiseSigPVals(_PairwiseSigTStats):
+    """Provides pairwise significance p-vals measure for matrix and selected subvar.
+
+    Pairwise significance is calculated for each selected subvar (column) separately.
+    """
+
+    @lazyproperty
+    def blocks(self):
+        """2D array of the four 2D "blocks" making up this measure."""
+        return NanSubtotals.blocks(self._p_vals, self._dimensions)
+
+    @lazyproperty
+    def _p_vals(self):
+        """2D ndarray of float64 representing p-vals for pairwise MR testing.
+
+        For each (category) row, we calculate the test significance of the overlap
+        between columns (subvariables) of the crossing MR variable. To do that we have
+        to iterate across all categories (rows), and then across all subvars (columns).
+        Each of these iterations produces a single number for the significance, so we
+        end up with n_rows x n_cols 2-dimensional ndarray.
+        """
+        return np.array(
+            [
+                [
+                    _PairwiseSignificaneBetweenSubvariablesHelper(
+                        self._cube_measures.cube_overlaps.overlaps[row_idx],
+                        self._cube_measures.cube_overlaps.valid_overlaps[row_idx],
+                        self._selected_subvar_idx,
+                        subvar_idx,
+                    ).p_vals
+                    for subvar_idx in range(self._n_subvars)
+                ]
+                for row_idx in range(self._n_rows)
+            ]
+        )
+
+
 class _RowProportions(_BaseSecondOrderMeasure):
     """Provides the row-proportions measure for a matrix.
 
@@ -395,7 +517,7 @@ class _RowProportions(_BaseSecondOrderMeasure):
         Row-proportions are counts divided by the row base, except that they are
         undefined for rows with subtotal differences.
         """
-        count_blocks = SumDiffSubtotals.blocks(
+        count_blocks = SumSubtotals.blocks(
             self._weighted_cube_counts.weighted_counts,
             self._dimensions,
             diff_rows_nan=True,
@@ -446,7 +568,9 @@ class _RowUnweightedBases(_BaseSecondOrderMeasure):
         # --- shape of the intersections. This works in the CAT_X case because each
         # --- column of subtotal-rows is the same. In the MR_X case there can be no
         # --- subtotal rows so just an empty column is broadcast.
-        shape = SumSubtotals.intersections(self._base_values, self._dimensions).shape
+        shape = SumSubtotals.intersections(
+            self._base_values, self._dimensions, diff_rows_nan=True
+        ).shape
         intersection_column = self._subtotal_rows[:, 0]
         return np.broadcast_to(intersection_column[:, None], shape)
 
@@ -461,7 +585,7 @@ class _RowUnweightedBases(_BaseSecondOrderMeasure):
         # --- initial subtotal-columns matrix is used only for its shape because it
         # --- computes the wrong values.
         subtotal_columns = SumSubtotals.subtotal_columns(
-            self._base_values, self._dimensions
+            self._base_values, self._dimensions, diff_rows_nan=True
         )
         # --- in the "no-column-subtotals" case, short-circuit with an (nrows, 0) array
         # --- return value, both because that is the right answer, but also because the
@@ -482,7 +606,9 @@ class _RowUnweightedBases(_BaseSecondOrderMeasure):
         # --- Summing works on rows because row-proportion denominators add along this
         # --- axis. This wouldn't work on MR-rows but there can be no subtotals on an
         # --- MR rows dimension (or any MR dimension) so that case never arises.
-        return SumSubtotals.subtotal_rows(self._base_values, self._dimensions)
+        return SumSubtotals.subtotal_rows(
+            self._base_values, self._dimensions, diff_rows_nan=True
+        )
 
 
 class _RowWeightedBases(_BaseSecondOrderMeasure):
@@ -526,7 +652,7 @@ class _RowWeightedBases(_BaseSecondOrderMeasure):
         # --- subtotal-columns matrix is used only for its shape because it computes
         # --- the wrong values.
         subtotal_columns = SumSubtotals.subtotal_columns(
-            self._base_values, self._dimensions
+            self._base_values, self._dimensions, diff_rows_nan=True
         )
         # --- in the "no-column-subtotals" case, short-circuit with an (nrows, 0) array
         # --- return value, both because that is the right answer, but also because the
@@ -547,7 +673,43 @@ class _RowWeightedBases(_BaseSecondOrderMeasure):
         # --- Summing works on rows because row-proportion denominators add along this
         # --- axis. This wouldn't work on MR-rows but there can be no subtotals on an
         # --- MR dimension (MR_X slice) so that case never arises.
-        return SumSubtotals.subtotal_rows(self._base_values, self._dimensions)
+        return SumSubtotals.subtotal_rows(
+            self._base_values, self._dimensions, diff_rows_nan=True
+        )
+
+
+class _ShareSum(_BaseSecondOrderMeasure):
+    """Provides the share of sum measure for a matrix.
+
+    Share of sum is the sum of each subvar item divided by the TOTAL number of items.
+    """
+
+    @lazyproperty
+    def blocks(self):
+        """2D array of the four 2D "blocks" making up this measure.
+
+        These are the base-values, the column-subtotals, the row-subtotals, and the
+        subtotal intersection-cell values.
+        """
+        sums_blocks = SumSubtotals.blocks(
+            self._cube_measures.cube_sum.sums, self._dimensions
+        )
+        # --- do not propagate divide-by-zero warnings to stderr ---
+        with np.errstate(divide="ignore", invalid="ignore"):
+            return [
+                [
+                    # --- base values ---
+                    sums_blocks[0][0] / np.sum(sums_blocks[0][0], axis=0),
+                    # --- inserted columns ---
+                    sums_blocks[0][1] / np.sum(sums_blocks[0][1], axis=0),
+                ],
+                [
+                    # --- inserted rows ---
+                    sums_blocks[1][0] / np.sum(sums_blocks[1][0], axis=0),
+                    # --- intersections ---
+                    sums_blocks[1][1] / np.sum(sums_blocks[1][1], axis=0),
+                ],
+            ]
 
 
 class _Sums(_BaseSecondOrderMeasure):
@@ -556,9 +718,7 @@ class _Sums(_BaseSecondOrderMeasure):
     @lazyproperty
     def blocks(self):
         """2D array of the four 2D "blocks" making up this measure."""
-        return SumDiffSubtotals.blocks(
-            self._cube_measures.cube_sum.sums, self._dimensions
-        )
+        return SumSubtotals.blocks(self._cube_measures.cube_sum.sums, self._dimensions)
 
 
 class _StdDev(_BaseSecondOrderMeasure):
@@ -810,7 +970,7 @@ class _UnweightedCounts(_BaseSecondOrderMeasure):
         These are the base-values, the column-subtotals, the row-subtotals, and the
         subtotal intersection-cell values.
         """
-        return SumDiffSubtotals.blocks(
+        return SumSubtotals.blocks(
             self._unweighted_cube_counts.unweighted_counts, self._dimensions
         )
 
@@ -821,6 +981,79 @@ class _WeightedCounts(_BaseSecondOrderMeasure):
     @lazyproperty
     def blocks(self):
         """2D array of the four 2D "blocks" making up this measure."""
-        return SumDiffSubtotals.blocks(
+        return SumSubtotals.blocks(
             self._weighted_cube_counts.weighted_counts, self._dimensions
         )
+
+
+# === PAIRWISE HELPERS ===
+
+
+class _PairwiseSignificaneBetweenSubvariablesHelper(object):
+    """Helper for calculating overlaps significance between subvariables."""
+
+    def __init__(self, overlaps, valid_overlaps, idx_a, idx_b):
+        self._overlaps = overlaps
+        self._valid_overlaps = valid_overlaps
+        self._idx_a = idx_a
+        self._idx_b = idx_b
+
+    @lazyproperty
+    def p_vals(self):
+        """float64 significance p-vals for the selected subvariables."""
+        return (
+            0.0
+            if self._idx_a == self._idx_b
+            else 2 * (1 - t.cdf(abs(self.t_stats), df=self._df - 2))
+        )
+
+    @lazyproperty
+    def t_stats(self):
+        """float64 significance t-stats for the selected subvariables."""
+        if self._idx_a == self._idx_b:
+            return 0.0
+
+        Sa, Sb, Sab = self._selected_counts
+        Na, Nb, Nab = self._valid_counts
+        pa, pb, pab = Sa / Na, Sb / Nb, Sab / Nab
+
+        return (pa - pb) / np.sqrt(
+            1 / self._df * (pa * (1 - pa) + pb * (1 - pb) + 2 * pa * pb - 2 * pab)
+        )
+
+    @lazyproperty
+    def _df(self):
+        """int representing degrees of freedom for the CDF distribution.
+
+        This is the count of non-overlapping cases of subvariables a and b.
+        """
+        Na, Nb, Nab = self._valid_counts
+        return Na + Nb - Nab
+
+    @lazyproperty
+    def _selected_counts(self):
+        """tuple(int/float64) of selected counts for subvars a, b, and combined (a^b).
+
+        Most often these numbers will be int, because that's how the database counts
+        if the responses are of the "Selected" category (row[idx] == 1). They can only
+        be float64 when the overlaps result is weighted.
+        """
+        return (
+            self._overlaps[self._idx_a, self._idx_a],
+            self._overlaps[self._idx_b, self._idx_b],
+            self._overlaps[self._idx_a, self._idx_b],
+        )
+
+    @lazyproperty
+    def _valid_counts(self):
+        """tuple(int/float64) of valid counts for subvars a, b, and combined (a^b).
+
+        Most often these numbers will be int, because that's how the database counts
+        if the responses are different than the "Missing" category (row[idx] != -1).
+        They can only be float64 when the overlaps result is weighted.
+        """
+        return (
+            self._valid_overlaps[self._idx_a, self._idx_a],
+            self._valid_overlaps[self._idx_b, self._idx_b],
+            self._valid_overlaps[self._idx_a, self._idx_b],
+        )
