@@ -150,65 +150,46 @@ class NanSubtotals(_BaseSubtotals):
 
 
 class SumSubtotals(_BaseSubtotals):
-    """Subtotal "blocks" created by np.sum() on addends and subtrahends.
+    """Subtotal "blocks" created by adding and subtracting terms for subtotals.
 
-    Used when calculating bases, for example, which are additive even across
-    subtrahends.
-    """
-
-    @classmethod
-    def intersections(cls, base_values, dimensions):
-        """Return (n_row_subtotals, n_col_subtotals) ndarray of intersection values.
-
-        An intersection value arises where a row-subtotal crosses a column-subtotal.
-        """
-        return cls(base_values, dimensions)._intersections
-
-    @classmethod
-    def subtotal_columns(cls, base_values, dimensions):
-        """Return (n_base_rows, n_col_subtotals) ndarray of subtotal columns."""
-        return cls(base_values, dimensions)._subtotal_columns
-
-    @classmethod
-    def subtotal_rows(cls, base_values, dimensions):
-        """Return (n_row_subtotals, n_base_cols) ndarray of subtotal rows."""
-        return cls(base_values, dimensions)._subtotal_rows
-
-    def _intersection(self, row_subtotal, column_subtotal):
-        """Sum for this row/column subtotal intersection."""
-        addend_sum = np.sum(
-            self._subtotal_row(row_subtotal)[column_subtotal.addend_idxs]
-        )
-        subtrahend_sum = np.sum(
-            self._subtotal_row(row_subtotal)[column_subtotal.subtrahend_idxs]
-        )
-        return addend_sum + subtrahend_sum
-
-    def _subtotal_column(self, subtotal):
-        """Return (n_rows,) ndarray of values for `subtotal` column."""
-        addend_sum = np.sum(self._base_values[:, subtotal.addend_idxs], axis=1)
-        subtrahend_sum = np.sum(self._base_values[:, subtotal.subtrahend_idxs], axis=1)
-        return addend_sum + subtrahend_sum
-
-    def _subtotal_row(self, subtotal):
-        """Return (n_cols,) ndarray of values for `subtotal` row."""
-        addend_sum = np.sum(self._base_values[subtotal.addend_idxs, :], axis=0)
-        subtrahend_sum = np.sum(self._base_values[subtotal.subtrahend_idxs, :], axis=0)
-        return addend_sum + subtrahend_sum
-
-
-class SumDiffSubtotals(_BaseSubtotals):
-    """Subtotal "blocks" created by adding and subtrahends, primarily counts.
-
-    In addition to `base_values` and `dimensions`, `SumDiffSubtotals` have
+    In addition to `base_values` and `dimensions`, `SumSubtotals` have
     properties for `diff_cols_nan` and `diff_rows_nan` which allow for columns/
-    rows where subtotals have subtrahends to be overidden with np.nan.
+    rows where subtotals have subtrahends to be overridden with np.nan. These are
+    used for measures such as bases (and measures derived from bases, like proportions)
+    that are not computed along the same direction as a subtotal difference. Example:
+    a subtotal difference in the row dimension does not have a valid row proportion.
+
+    One way of thinking about this is that when calculating proportions, users are
+    only interested in the direction of proportions where the difference is equal
+    to the sum of the addends minus the sum of the subtrahends. But when calculating
+    proportions along a row or column, the proportions are only additive in one
+    direction, so subtotal differences in the other direction don't work. For example,
+    when you go along a row and you are calculating column percents, each column
+    has a different base, so the proportions don't add up.
+
+    Example showing column percents. We do want to calculate column proportion for
+    `a-b`, but not `c-d` because `c-d` is a subtotal difference in the column
+    dimension.
+    ```
+    |     | c-d | c   | d   | c+d  |
+    |-----|-----|-----|-----|------|
+    | a-b | -   | 20  | 50  | 25   |
+    | a   | -   | 60  | 75  | 62.5 |
+    | b   | -   | 40  | 25  | 37.5 |
+    | a+b | -   | 100 | 100 | 100  |
+    ```
+
+    Another way to think about it is that a "base" is a positive thing, so you can't
+    really subtract out the subtrahends. One option would be to add both the addends and
+    the subtrahends, but ultimately we decided that users would be confused by
+    by these values, and they really only want to see the base and proportions in the
+    opposing direction. Therefore we set the corresponding direction to nan.
     """
 
     def __init__(
         self, base_values, dimensions, diff_cols_nan=False, diff_rows_nan=False
     ):
-        super(SumDiffSubtotals, self).__init__(base_values, dimensions)
+        super(SumSubtotals, self).__init__(base_values, dimensions)
         self._diff_cols_nan = diff_cols_nan
         self._diff_rows_nan = diff_rows_nan
 
@@ -217,6 +198,12 @@ class SumDiffSubtotals(_BaseSubtotals):
         """Return base, row and col insertion, and intersection matrices.
 
         These are in the form ready for assembly.
+
+        Keyword arguments:
+        `diff_cols_nan` -- Overrides subtotal differences in the columns direction eg for
+        column bases (default False)
+        `diff_rows_nan` -- Overrides subtotal differences in the rows direction eg for
+        row bases (default False)
         """
         return cls(base_values, dimensions, diff_cols_nan, diff_rows_nan)._blocks
 
@@ -227,6 +214,12 @@ class SumDiffSubtotals(_BaseSubtotals):
         """Return (n_row_subtotals, n_col_subtotals) ndarray of intersection values.
 
         An intersection value arises where a row-subtotal crosses a column-subtotal.
+
+        Keyword arguments:
+        `diff_cols_nan` -- Overrides subtotal differences in the columns direction eg for
+        column bases (default False)
+        `diff_rows_nan` -- Overrides subtotal differences in the rows direction eg for
+        row bases (default False)
         """
         return cls(base_values, dimensions, diff_cols_nan, diff_rows_nan)._intersections
 
@@ -234,7 +227,14 @@ class SumDiffSubtotals(_BaseSubtotals):
     def subtotal_columns(
         cls, base_values, dimensions, diff_cols_nan=False, diff_rows_nan=False
     ):
-        """Return (n_base_rows, n_col_subtotals) ndarray of subtotal columns."""
+        """Return (n_base_rows, n_col_subtotals) ndarray of subtotal columns.
+
+        Keyword arguments:
+        `diff_cols_nan` -- Overrides subtotal differences in the columns direction eg for
+        column bases (default False)
+        `diff_rows_nan` -- Overrides subtotal differences in the rows direction eg for
+        row bases (default False)
+        """
         return cls(
             base_values, dimensions, diff_cols_nan, diff_rows_nan
         )._subtotal_columns
@@ -243,7 +243,14 @@ class SumDiffSubtotals(_BaseSubtotals):
     def subtotal_rows(
         cls, base_values, dimensions, diff_cols_nan=False, diff_rows_nan=False
     ):
-        """Return (n_row_subtotals, n_base_cols) ndarray of subtotal rows."""
+        """Return (n_row_subtotals, n_base_cols) ndarray of subtotal rows.
+
+        Keyword arguments:
+        `diff_cols_nan` -- Overrides subtotal differences in the columns direction eg for
+        column bases (default False)
+        `diff_rows_nan` -- Overrides subtotal differences in the rows direction eg for
+        row bases (default False)
+        """
         return cls(base_values, dimensions, diff_cols_nan, diff_rows_nan)._subtotal_rows
 
     def _intersection(self, row_subtotal, column_subtotal):
