@@ -7,7 +7,7 @@ from __future__ import division
 import numpy as np
 
 from cr.cube.stripe.cubemeasure import CubeMeasures
-from cr.cube.stripe.insertion import NanSubtotals, SumDiffSubtotals, SumSubtotals
+from cr.cube.stripe.insertion import NanSubtotals, SumSubtotals
 from cr.cube.util import lazyproperty
 
 
@@ -47,6 +47,11 @@ class StripeMeasures(object):
         """
         return _ScaledCounts(self._rows_dimension, self, self._cube_measures)
 
+    @lazyproperty
+    def share_sum(self):
+        """_ShareSum measure object for this stripe."""
+        return _ShareSum(self._rows_dimension, self, self._cube_measures)
+
     @lazyproperty
     def stddev(self):
         """_StdDev measure object for this stripe."""
@@ -315,6 +320,24 @@ class _ScaledCounts(_BaseSecondOrderMeasure):
         return self._weighted_cube_counts.weighted_counts[self._has_numeric_value]
 
 
+class _ShareSum(_BaseSecondOrderMeasure):
+    """Provides the share of sum measure for a stripe.
+
+    Relies on the presence of a sum cube-measure in the cube-result.
+    """
+
+    @lazyproperty
+    def base_values(self):
+        """1D np.float64 ndarray of share of sum for each row."""
+        sums = self._cube_measures.cube_sum.sums
+        return sums / np.sum(sums)
+
+    @lazyproperty
+    def subtotal_values(self):
+        """1D ndarray of share of sum subtotals for each row-subtotal."""
+        return SumSubtotals.subtotal_values(self.base_values, self._rows_dimension)
+
+
 class _StdDev(_BaseSecondOrderMeasure):
     """Provides the stddev measure for a stripe.
 
@@ -506,7 +529,7 @@ class _UnweightedCounts(_BaseSecondOrderMeasure):
         # --- counts don't sum on an MR dimension, but an MR stripe can have no
         # --- subtotals. This just returns an empty array in that case and we don't need
         # --- to special-case MR.
-        return SumDiffSubtotals.subtotal_values(self.base_values, self._rows_dimension)
+        return SumSubtotals.subtotal_values(self.base_values, self._rows_dimension)
 
 
 class _WeightedBases(_BaseSecondOrderMeasure):
@@ -573,4 +596,4 @@ class _WeightedCounts(_BaseSecondOrderMeasure):
         # --- counts don't sum on an MR dimension, but an MR stripe can have no
         # --- subtotals. This just returns an empty array in that case and we don't need
         # --- to special-case MR.
-        return SumDiffSubtotals.subtotal_values(self.base_values, self._rows_dimension)
+        return SumSubtotals.subtotal_values(self.base_values, self._rows_dimension)
