@@ -399,20 +399,20 @@ class DescribeAssembler(object):
         dimensions_,
         _cube_result_matrix_prop_,
         cube_result_matrix_,
-        SumDiffSubtotals_,
+        SumSubtotals_,
         _assemble_matrix_,
     ):
         _columns_dimension_prop_.return_value = dimensions_[1]
         dimensions_[1].dimension_type = DT.MR_SUBVAR
         cube_result_matrix_.rows_margin = [[1, 2], [3, 4]]
         _cube_result_matrix_prop_.return_value = cube_result_matrix_
-        SumDiffSubtotals_.blocks.return_value = [[[1], [2]], [[3], [4]]]
+        SumSubtotals_.blocks.return_value = [[[1], [2]], [[3], [4]]]
         _assemble_matrix_.return_value = [[1, 2, 3], [4, 5, 6], [7, 8, 9]]
         assembler = Assembler(None, dimensions_, None)
 
         rows_margin = assembler.rows_margin
 
-        SumDiffSubtotals_.blocks.assert_called_once_with([[1, 2], [3, 4]], dimensions_)
+        SumSubtotals_.blocks.assert_called_once_with([[1, 2], [3, 4]], dimensions_)
         _assemble_matrix_.assert_called_once_with(assembler, [[[1], [2]], [[3], [4]]])
         assert rows_margin == [[1, 2, 3], [4, 5, 6], [7, 8, 9]]
 
@@ -925,10 +925,6 @@ class DescribeAssembler(object):
     def subtotals_(self, request):
         return instance_mock(request, _Subtotals)
 
-    @pytest.fixture
-    def SumDiffSubtotals_(self, request):
-        return class_mock(request, "cr.cube.matrix.assembler.SumDiffSubtotals")
-
     @pytest.fixture
     def SumSubtotals_(self, request):
         return class_mock(request, "cr.cube.matrix.assembler.SumSubtotals")
