@@ -384,24 +384,29 @@ class Describe_RawDimension(object):
         assert dimension_type == expected_value
 
     @pytest.mark.parametrize(
-        "is_array_cat, has_selected_cat, expected_value",
+        "is_array_cat, has_selected_cat, is_logical_type, expected_value",
         (
-            (False, False, DT.CAT),
-            (False, True, DT.LOGICAL),
-            (True, False, DT.CA_CAT),
-            (True, True, DT.MR_CAT),
+            (False, False, False, DT.CAT),
+            (False, True, False, DT.CAT),
+            (False, True, True, DT.LOGICAL),
+            (True, False, False, DT.CA_CAT),
+            (True, True, True, DT.MR_CAT),
+            (True, True, False, DT.CA_CAT),
         ),
     )
     def it_resolves_a_categorical_type_to_help(
         self,
         is_array_cat,
         has_selected_cat,
+        is_logical_type,
         expected_value,
         _is_array_cat_prop_,
         _has_selected_category_prop_,
+        _is_logical_type_prop_,
     ):
         _is_array_cat_prop_.return_value = is_array_cat
         _has_selected_category_prop_.return_value = has_selected_cat
+        _is_logical_type_prop_.return_value = is_logical_type
         raw_dimension = _RawDimension(None, None)
 
         dimension_type = raw_dimension._resolve_categorical()
@@ -426,6 +431,10 @@ class Describe_RawDimension(object):
     def _is_array_cat_prop_(self, request):
         return property_mock(request, _RawDimension, "_is_array_cat")
 
+    @pytest.fixture
+    def _is_logical_type_prop_(self, request):
+        return property_mock(request, _RawDimension, "_is_logical_type")
+
     @pytest.fixture
     def _next_raw_dimension_prop_(self, request):
         return property_mock(request, _RawDimension, "_next_raw_dimension")
@@ -1074,17 +1083,13 @@ class Describe_Subtotals(object):
             (["not-a-dict", None], (), ()),
             ([{"function": "hyperdrive"}], (), ()),
             ([{"function": "subtotal", "arghhs": []}], (), ()),
+            ([{"function": "subtotal", "anchor": 9, "name": "no args"}], (), ()),
             ([{"function": "subtotal", "anchor": 9, "args": [1, 2]}], (), ()),
             (
                 [{"function": "subtotal", "anchor": 9, "args": [1, 2], "name": "A"}],
                 {3, 4},
                 (),
             ),
-            (
-                [{"function": "subtotal", "anchor": 9, "args": [1, 2], "name": "B"}],
-                {1, 2, 3, 4, 5, 8, -1},
-                ({"function": "subtotal", "anchor": 9, "args": [1, 2], "name": "B"},),
-            ),
             (
                 [
                     {"function": "subtotal", "anchor": 9, "args": [1, 2], "name": "C"},
@@ -1099,7 +1104,7 @@ class Describe_Subtotals(object):
             ),
         ),
     )
-    def it_iterates_the_valid_subtotal_insertion_dicts_to_help(
+    def it_removes_invalid_when_iterating_the_valid_subtotal_insertion_dicts_to_help(
         self, insertion_dicts, element_ids, expected_value, _element_ids_prop_
     ):
         _element_ids_prop_.return_value = element_ids
@@ -1109,6 +1114,47 @@ class Describe_Subtotals(object):
 
         assert subtotal_dicts == expected_value
 
+    def but_it_accepts_valid_insertion_dicts(self, _element_ids_prop_):
+        _element_ids_prop_.return_value = {1, 2, 5, 8, -1}
+        insertion_dicts = [
+            {
+                "function": "subtotal",
+                "anchor": 9,
+                "args": [1],
+                "name": "old style args",
+            },
+            {
+                "function": "subtotal",
+                "anchor": 9,
+                "args": [1],
+                "kwargs": {"negative": [2]},
+                "name": "old style args with negative",
+            },
+            {
+                "function": "subtotal",
+                "anchor": 9,
+                "kwargs": {"negative": [2]},
+                "name": "negative only",
+            },
+            {
+                "function": "subtotal",
+                "anchor": 9,
+                "kwargs": {"positive": [1]},
+                "name": "new style kwargs",
+            },
+            {
+                "function": "subtotal",
+                "anchor": 9,
+                "kwargs": {"positive": [1], "negative": [2]},
+                "name": "new style kwargs with negative",
+            },
+        ]
+        subtotals = _Subtotals(insertion_dicts, None)
+
+        subtotal_dicts = tuple(subtotals._iter_valid_subtotal_dicts())
+
+        assert subtotal_dicts == tuple(insertion_dicts)
+
     def it_constructs_its_subtotal_objects_to_help(
         self, request, _iter_valid_subtotal_dicts_, valid_elements_, _Subtotal_
     ):
@@ -1219,6 +1265,8 @@ class Describe_Subtotal(object):
             ({"args": [3, 2]}, {1, 2, 3}, (3, 2)),
             ({"args": []}, {1, 2, 3}, ()),
             ({"args": [1, 2, 3]}, {}, ()),
+            ({"kwargs": {"positive": [1, 2, 3]}}, {1, 2, 3}, (1, 2, 3)),
+            ({"args": [1], "kwargs": {"positive": [2]}}, {1, 2, 3}, (2,)),
         ),
     )
     def it_provides_access_to_the_addend_element_ids(
